import pygame

pygame.init()
font = pygame.font.SysFont("Arial", 30)

class slider:
    def __init__(self,x,y,text,colorOfText,screen,sliderIMG,barIMG):
        super().__init__()
        self.image = sliderIMG
        self.bar = barIMG
        self.rect = self.image.get_rect()
        self.rect.center = [x,y]
        self.barRect = self.bar.get_rect()
        self.barRect.center = [x,y]
        self.value = 127.5
        self.held = False
        self.text = font.render(text,True,colorOfText)
        self.valueText = font.render(str(self.value),True,colorOfText)
        self.valueString = "value here"
        self.screen = screen
        self.colorOfText = colorOfText
    def update(self):
        self.rect.clamp_ip(self.barRect)
        self.screen.blit(self.bar,(self.barRect.x,self.barRect.y))
        self.screen.blit(self.image,(self.rect.x,self.rect.y))
        self.screen.blit(self.text , (self.barRect.right + 20, self.barRect.y - 10))
        pos = pygame.mouse.get_pos()

        self.value = (self.rect.x - self.barRect.left) * 2
        
        if self.rect.collidepoint(pos):
            if pygame.mouse.get_pressed()[0] == 1:
                self.held = True

        if pygame.mouse.get_pressed()[0] == 0:
                self.held = False

        if (self.held):
                self.rect.x = pos[0] - 8
                if self.rect.x > self.barRect.right - 14:
                    self.rect.x = self.barRect.right - 14
                    self.value = 255

                if self.rect.x < self.barRect.left:
                    self.rect.x = self.barRect.left
        self.valueString = str(self.value)
        self.valueText = font.render(self.valueString,True,self.colorOfText)

        self.screen.blit(self.valueText , (self.barRect.x + 50, self.barRect.y - 40))


from setuptools import setup, find_packages

classifiers = ['Development Status :: 5 - Production/Stable',
'Intended Audience :: Developers',
'Operating System :: Microsoft :: Windows :: Windows 10',
'License :: OSI Approved :: MIT License',
'Programming Language :: Python :: 3.6'
]

setup(
name='SpeedsUtilities',
version='0.0.2',
description='A few utlitites',
long_description=open('README.txt').read() + '\n\n' + open('CHANGELOG.txt').read(),
url='',
author='Pavel Martinek',
author_email='pavlicekcz292@gmail.com',
license='MIT',
classifiers=classifiers,
keywords='button',
packages=find_packages(),
install_requires=['pygame']
)


import pygame

pygame.init()
font = pygame.font.SysFont("Arial", 30)

class button:
    def __init__(self,x,y,text_x,text_y,text,colorOfText,screen,image,startingValue,codeToExecute,isTextInCentre):
        super().__init__()
        self.image = image
        self.rect = self.image.get_rect()
        self.rect.center = [x,y]
        self.displayed_text = font.render(text,True,colorOfText)
        self.text = text
        self.screen = screen
        self.value = startingValue
        self.onPress = codeToExecute
        self.colorOftext = colorOfText
        self.text_x = text_x
        self.text_y = text_y
        self.rectText = self.displayed_text.get_rect()
        self.rectText.center = [x,y]
        self.isHeld = False
        self.isTextInCentre = isTextInCentre
    def update(self):
        self.screen.blit(self.image,(self.rect.x,self.rect.y))

        pos = pygame.mouse.get_pos()

        if self.rect.collidepoint(pos):
            if pygame.mouse.get_pressed()[0] == 1:
                if self.isHeld == False:
                    self.onPress()
                    self.isHeld = True

        if  pygame.mouse.get_pressed()[0] == 0:
            self.isHeld = False

        
        if self.isTextInCentre ==  True:
            self.screen.blit(self.displayed_text , (self.rectText.x, self.rectText.y))
        else:
            self.screen.blit(self.displayed_text , (self.text_x, self.text_y))